==> haskell-src-meta-0.8.15-48-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-src-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-src-meta
version:              0.8.15
visibility:           public
id:                   haskell-src-meta-0.8.15-BGyGaHJjFOe92TlKdTyhDU
key:                  haskell-src-meta-0.8.15-BGyGaHJjFOe92TlKdTyhDU
license:              BSD-3-Clause
copyright:            (c) Matt Morrow
maintainer:           danburton.email@gmail.com
author:               Matt Morrow
synopsis:             Parse source to template-haskell abstract syntax.
description:
    The translation from haskell-src-exts abstract syntax
    to template-haskell abstract syntax isn'\''t 100% complete yet.

category:             Language, Template Haskell
abi:                  0835701368a50d1b6cb047435d78b0b7
exposed:              True
exposed-modules:
    Language.Haskell.Meta Language.Haskell.Meta.Extensions
    Language.Haskell.Meta.Parse Language.Haskell.Meta.Syntax.Translate
    Language.Haskell.Meta.Utils

hidden-modules:       Language.Haskell.Meta.THCompat
import-dirs:          /usr/lib/ghc-9.4.8/site-local/haskell-src-meta-0.8.15
library-dirs:         /usr/lib/ghc-9.4.8/site-local/haskell-src-meta-0.8.15
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/haskell-src-meta-0.8.15
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-meta
hs-libraries:         HShaskell-src-meta-0.8.15-BGyGaHJjFOe92TlKdTyhDU
depends:
    base-4.17.2.1 haskell-src-exts-1.23.1-8YCvwGoz5v65yIba8GoVHN
    pretty-1.1.3.6 syb-0.7.3-6VXQKmiHaWYG9qlQr6p3GQ
    template-haskell-2.19.0.0 th-orphans-0.13.16-25alF1uAvIHBksMsSibN4X

haddock-interfaces:
    /usr/share/doc/haskell-src-meta/html/haskell-src-meta.haddock

haddock-html:         /usr/share/doc/haskell-src-meta/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-meta-0.8.15-49-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-src-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-src-meta
version:              0.8.15
visibility:           public
id:                   haskell-src-meta-0.8.15-GcWNIWVHiGQBjlHG1sYidx
key:                  haskell-src-meta-0.8.15-GcWNIWVHiGQBjlHG1sYidx
license:              BSD-3-Clause
copyright:            (c) Matt Morrow
maintainer:           danburton.email@gmail.com
author:               Matt Morrow
synopsis:             Parse source to template-haskell abstract syntax.
description:
    The translation from haskell-src-exts abstract syntax
    to template-haskell abstract syntax isn'\''t 100% complete yet.

category:             Language, Template Haskell
abi:                  7cf537c07305e95ea27746de4f1e860f
exposed:              True
exposed-modules:
    Language.Haskell.Meta Language.Haskell.Meta.Extensions
    Language.Haskell.Meta.Parse Language.Haskell.Meta.Syntax.Translate
    Language.Haskell.Meta.Utils

hidden-modules:       Language.Haskell.Meta.THCompat
import-dirs:          /usr/lib/ghc-9.4.8/site-local/haskell-src-meta-0.8.15
library-dirs:         /usr/lib/ghc-9.4.8/site-local/haskell-src-meta-0.8.15
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/haskell-src-meta-0.8.15
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-meta
hs-libraries:         HShaskell-src-meta-0.8.15-GcWNIWVHiGQBjlHG1sYidx
depends:
    base-4.17.2.1 haskell-src-exts-1.23.1-6lePEDtRHy8J6JhqOxjATA
    pretty-1.1.3.6 syb-0.7.3-BQUcn35RmaZ45KQPDd3rN
    template-haskell-2.19.0.0 th-orphans-0.13.16-HLpqMPURxZkLn5WCksfXEG

haddock-interfaces:
    /usr/share/doc/haskell-src-meta/html/haskell-src-meta.haddock

haddock-html:         /usr/share/doc/haskell-src-meta/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
